@@ -21,7 +21,8 @@ enum ISA {
     SKX_AVX512 = 8,
     ICL_AVX512 = 9,
     SPR_AVX512 = 10,
-    AVX10_2 = 11,
+    GNR_AVX512 = 11,
+    DMR_AVX10_2 = 12,
 
     COUNT
 };
@@ -195,7 +196,7 @@ UNUSED_ATTR static enum ISA get_x86_isa() {
         UNUSED_ATTR int tgl = icl && avx512_vp2intersect;
         int spr =
             icl && avx512_bf16 && avx512_amx_bf16 && avx512_amx_tile && avx512_amx_int8 && avx_vnni && avx512_fp16;
-        UNUSED_ATTR int gnr = spr && amxfp16 && prefetchi;
+        int gnr = spr && amxfp16 && prefetchi;
 
         int avx10 = (info3[3] & (1 << 19)) != 0;
 
@@ -217,10 +218,12 @@ UNUSED_ATTR static enum ISA get_x86_isa() {
                       amxcomplex && sha512 && sm3 && sm4;
 
             if (dmr) {
-                return AVX10_2;
+                return DMR_AVX10_2;
             }
         }
-        if (spr) {
+        if (gnr) {
+            return GNR_AVX512;
+        } else if (spr) {
             return SPR_AVX512;
         } else if (icl) {
             return ICL_AVX512;
